@@ -13,11 +13,11 @@ class Client:
 		self.configuration = configuration
 
 	def get(self, path, payload = {}):
-		r = requests.get(self.url(path), params=payload, headers = self.headers())
+		r = requests.get(self.url(path), params=payload, headers = self.headers(), timeout = self.configuration.timeout)
 		return self.handle_response(r)
 
 	def post(self, path, payload):
-		r = requests.post(self.url(path), json=payload, headers = self.headers())
+		r = requests.post(self.url(path), json=payload, headers = self.headers(), timeout = self.configuration.timeout)
 		return self.handle_response(r)
 
 	def handle_response(self, r):
